Evaluate

Trait Evaluate 

pub trait Evaluate<T, U> {
    // Required method
    fn evaluate(&self, value: T) -> U;
}
Is implemented by polynomials to evaluate them for a certain input.

Required Methods

fn evaluate(&self, value: T) -> U

Evaluates the object, e.g. polynomial or a matrix of polynomials, for a given input value.

Parameters:

  • value: the value with which to evaluate the object.

Returns the evaluation of the object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Evaluate<&Zq, Zq> for PolyOverZq

Source

impl Evaluate<Zq, Zq> for PolyOverZq

Source

impl<Integer: Into<Z>> Evaluate<Integer, MatZ> for MatPolyOverZ

Source

impl<Integer: Into<Z>> Evaluate<Integer, Z> for PolyOverZ

Source

impl<Integer: Into<Z>> Evaluate<Integer, Zq> for PolyOverZq

Source

impl<Rational: Into<Q>> Evaluate<Rational, Q> for PolyOverQ

Source

impl<Rational: Into<Q>> Evaluate<Rational, Q> for PolyOverZ