MatrixDimensions

Trait MatrixDimensions 

pub trait MatrixDimensions {
    // Required methods
    fn get_num_rows(&self) -> i64;
    fn get_num_columns(&self) -> i64;
}
Is implemented by matrices to get the number of rows and number of columns of the matrix.

Required Methods

fn get_num_rows(&self) -> i64

Returns the number of rows of a matrix.

fn get_num_columns(&self) -> i64

Returns the number of columns of a matrix.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors